#
# spec file
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global artifactId jline
Name:           %{artifactId}1
Version:        1.0
Release:        2.8
Summary:        Java library for reading and editing user input in console applications
License:        BSD-3-Clause
Group:          Development/Libraries/Java
URL:            http://jline.sourceforge.net/
Source0:        http://download.sourceforge.net/sourceforge/%{artifactId}/%{artifactId}-%{version}.zip
Source1:        CatalogManager.properties
Source2:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  fdupes
BuildRequires:  javapackages-local
BuildRequires:  unzip
BuildRequires:  xml-commons-resolver
#!BuildIgnore:  antlr
#!BuildIgnore:  antlr-java

%description
JLine is a java library for reading and editing user input in console
applications. It features tab-completion, command history, password
masking, customizable keybindings, and pass-through handlers to use to
chain to other console applications.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML
BuildArch:      noarch

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n %{artifactId}-%{version}

# Make sure upstream hasn't sneaked in any jars we don't know about
find -name '*.class' -exec rm -f '{}' \;
find -name '*.jar' -exec rm -f '{}' \;

# Remove pre-built Windows-only binary artifacts
rm src/src/main/resources/jline/jline*.dll

# Use locally installed DTDs
mkdir build
cp -p %{SOURCE1} build/

cp -p %{SOURCE2} src/build.xml

%build
# Use locally installed DTDs
export CLASSPATH=%{_builddir}/%{name}-%{version}/build

mv src tmp
mv tmp/* .

%{ant} jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_jnidir}/%{name}
install -pm 0644 target/%{artifactId}-%{version}.jar %{buildroot}%{_jnidir}/%{name}/%{artifactId}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
install -pm 0644 pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{artifactId}.pom
%add_maven_depmap %{name}/%{artifactId}.pom %{name}/%{artifactId}.jar -v %{version},1
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE.txt

%files javadoc
%{_javadocdir}

%changelog
* Fri Mar 18 2022 Fridrich Strba <fstrba@suse.com>
- Build with source/target levels 8
* Tue Feb 12 2019 Fridrich Strba <fstrba@suse.com>
- Rename to jline1 and upgrade to 1.0
- Package it as a compatibility version
* Wed Sep 27 2017 fstrba@suse.com
- Don't require java-1_5_0-gcj-compat, but build with any
  java-devel provider
- Specify java source and target level 1.6: fixes build with
  jdk9
* Fri Jun  9 2017 tchvatal@suse.com
- Reduce depgraph and drop maven fragment to allow bootstrap
* Fri May 19 2017 mpluskal@suse.com
- Update dependencies
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Mon Aug 26 2013 mvyskocil@suse.com
- use new add_maven_depmap from javapackages-utils
* Thu Apr 25 2013 mvyskocil@suse.com
- add findutils dependency (bnc#816314)
* Thu Sep  2 2010 mvyskocil@suse.cz
- ignore antlr(-java) to reduce build cycles
* Wed Nov 18 2009 mvyskocil@suse.cz
- Build using gcj - needed by rhino 1.7R2 - bnc#554532
* Thu May  7 2009 mvyskocil@suse.cz
- Initial SUSE packaging 0.9.94 from jpp 5.0
